@@ -1,11 +1,12 @@
-#![cfg(feature = "random")]
+#![doc(cfg(feature = "rand_num"))]
+#![cfg(feature = "rand_num")]
 
-use crate::{Layout, Node, Random, Variant, Version};
+use crate::{Layout, Node, Variant, Version, UUID};
 use rand as random;
 
-impl Random {
-    /// New UUID from truly random number.
-    pub fn new() -> Layout {
+impl UUID {
+    /// New UUID version-4 from truly-random number
+    pub fn new_from_rand() -> Layout {
         let rand = random::random::<u128>().to_le_bytes();
         Layout {
             field_low: ((rand[0] as u32) << 24)
@@ -23,10 +24,11 @@ impl Random {
 }
 
 /// `UUID` version-4
+#[doc(cfg(feature = "rand_num"))]
 #[macro_export]
 macro_rules! v4 {
     () => {
-        format!("{:x}", $crate::Random::new().as_bytes())
+        format!("{:x}", $crate::UUID::new_from_rand().as_bytes())
     };
 }
 
@@ -35,8 +37,8 @@ mod tests {
     use super::*;
 
     #[test]
-    fn new_v4() {
-        let uuid = Random::new();
+    fn new_from_rand() {
+        let uuid = UUID::new_from_rand();
         assert_eq!(uuid.get_version(), Some(Version::RAND));
         assert_eq!(uuid.get_variant(), Some(Variant::RFC));
     }
